//+------------------------------------------------------------------+
//|                                                     ClearSID.mq4 |
//|                                     Copyright  2012, J. L. Hunt |
//|                                                                  |
//| Clears Sid the superstitious robot's database                    |
//| Version 0.14 beta                                                |
//|                                                                  |
//| This program is free software: you can redistribute it and/or    |
//| modify it under the terms of the GNU General Public License      |
//| as published by the Free Software Foundation, either version 2   |
//| of the License, or (at your option) any later version.           |
//|                                                                  |
//| This program is distributed in the hope that it will be useful,  |
//| but WITHOUT ANY WARRANTY; without even the implied warranty of   |
//| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the     |
//| GNU General Public License for more details.                     |
//|                                                                  |
//| You should have received a copy of the GNU General Public        |
//| License along with this program.                                 |
//| If not, see <http://www.gnu.org/licenses/gpl.html>               |
//|                                                                  |
//| This script clears Sid's MySQL database.                         |
//|                                                                  |
//|                   http://superstitiousthoughts.com/              |
//|                   http://community.trading-gurus.com/threads/??? |
//+------------------------------------------------------------------+
//+ Revision History                                                 +
//+                                                                  +
//+ 0.14 - May 21st 2012                                             +
//+        Added support for "Summary" table                         +
//+                                                                  +
//+ 0.13 - May 16th 2012                                             +
//+------------------------------------------------------------------+
#property copyright "Copyright  2012, J. L. Hunt"
#property link      "http://community.trading-gurus.com/threads/150"
#property show_inputs

#define ROBOT_NAME   "ClearSID"
#define VERSION      "v0.14 beta"

#import "libmysql.dll"
int    mysql_init(int handle); 
int    mysql_real_connect(int handle,string host, string user, string password, string schema, int port, int socket, int clientflag); 
int    mysql_real_query(int handle, string query, int length); 
void   mysql_close(int handle); 
int    mysql_errno(int handle); 
string mysql_error(int handle); 
#import

//---- Input parameters
extern string  host = "localhost";  // MySQL server host
extern int     port = 3306;         // MySQL server port
extern string  schema = "SuperstitiousSid";  // MySQL database name
extern string  user = "admin";      // MySQL username
extern string  password = "abc123"; // MySQL passowrd

static int     mysql = 0; 
static string  StrategyName;

//+------------------------------------------------------------------+
//| Utility functions                                                |
//+------------------------------------------------------------------+
#include <stdlib.mqh>
#include <stderror.mqh>
#include <WinUser32.mqh>

//+------------------------------------------------------------------+
//| Expert helper functions                                          |
//+------------------------------------------------------------------+

void db_connect() { 
   mysql = mysql_init(0); 
   if (mysql == 0) {
      Print("MySQL initialisation error");
      return; 
   }
   else
      Print("MySQL initialised"); 
   int res = mysql_real_connect(mysql, host, user, password, schema, port,"", 0); 
   if (res == mysql)
      Print("MySQL connected"); 
   else
      Print("MySQL error = ", mysql_error(mysql), " (", mysql_errno(mysql), ")"); 
} 

void db_disconnect() { 
   mysql_close(mysql); 
   Print("MySQL disconnected"); 
}

//+------------------------------------------------------------------+
//| Clears lucky number details in database                          |
//+------------------------------------------------------------------+
void db_clear_numbers()
{
   string query = "update `LuckyNumbers` set `Rank` = 0";

   if (mysql_real_query(mysql, query, StringLen(query)) != 0) {
      Print("MySQL error = ", mysql_error(mysql), " (", mysql_errno(mysql), ") clearing lucky numbers on host " + host);
      Print("Query = ", query);
   }   
}
   
//+------------------------------------------------------------------+
//| Clears trade details in database                                 |
//+------------------------------------------------------------------+
void db_clear_trades()
{
   string query = "delete from `Trades`";

   if (mysql_real_query(mysql, query, StringLen(query)) != 0) {
      Print("MySQL error = ", mysql_error(mysql), " (", mysql_errno(mysql), ") clearing trades on host " + host);
      Print("Query = ", query);
   }   
}
   
//+------------------------------------------------------------------+
//| Clears summary details in database                               |
//+------------------------------------------------------------------+
void db_clear_summary()
{
   string query = "delete from `Summary`";

   if (mysql_real_query(mysql, query, StringLen(query)) != 0) {
      Print("MySQL error = ", mysql_error(mysql), " (", mysql_errno(mysql), ") clearing summary on host " + host);
      Print("Query = ", query);
   }   
}
   
//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+
int init()
{
   StrategyName = StringConcatenate(ROBOT_NAME, " ", VERSION);

   Print(StrategyName, " initialized OK");

   return(0);
}

//+------------------------------------------------------------------+
//| Expert deinitialization function                                 |
//+------------------------------------------------------------------+
int deinit()
{
    Print(StrategyName, " deinitialized OK");
   
    return(0);
}

//+------------------------------------------------------------------+
//| Script start function                                            |
//+------------------------------------------------------------------+
int start()
{
   db_connect();
   db_clear_numbers();
   db_clear_trades();
   db_clear_summary();
   db_disconnect();

   return(0);
}

